@@ -193,7 +193,7 @@ struct IncrementalControl : Gringo::Control, Gringo::GringoModule {
     virtual ~IncrementalControl() { }
     virtual Gringo::Value parseValue(std::string const &str) { return termParser.parse(str); }
     virtual Control *newControl(int, char const **) { throw std::logic_error("creating new control instances not supported in gringo"); }
-    virtual void freeControl(Control *) { throw std::logic_error("creating new control instances not supported in gringo"); }
+    virtual void freeControl(Control *) { }
     virtual void cleanupDomains() { }
 
     Gringo::Input::GroundTermParser        termParser;
